# quantimpy

Welcome to QuantImPy, a Python library for scientific image processing.

This code performs morphological operations on Numpy arrays and can compute the
Minkowski functionals and functions.

This code is inspired by and partly based on the [QuantIm
library](https://www.ufz.de/index.php?en=39198) C/C++ library for scientific
image processing.

Documentation can be found on [Github.io](https://boeleman.github.io/quantimpy/)

This library can be installed using pip:

`pip install quantimpy`
